use std::net::{IpAddr, Ipv4Addr, SocketAddr};
use warp::Filter;

fn gm_paths() -> impl Filter {
    let base = warp::path("gm").and(warp::header("authentication"));

    let character_sheet = base
        .clone()
        .and(warp::path!("character" / String))
        .map(|auth: String, name| format!("name: {}", name));
    let send_item = base
        .clone()
        .and(warp::path("send_item"))
        .map(|auth| format!("send_item"));
    let send_resource = base
        .clone()
        .and(warp::path("send_resource"))
        .map(|auth| format!("send_resource"));

    character_sheet.or(send_item).or(send_resource)
}

fn player_paths() -> impl Filter {
    let base = warp::path("player").and(warp::header("authentication"));
    let character_sheet = base
        .and(warp::path!("character" / String))
        .map(|authentication: String, name: String| format!("name: {}", name));

    character_sheet
}

#[tokio::main]
pub async fn main() {
    let hi = warp::path!("hello" / String)
        .and(warp::header("user-agent"))
        .map(|param: String, agent: String| format!("Saluton! {}, {}", param, agent));
    let bye = warp::path!("goodbye").map(|| "Goodbye!");

    let server = warp::serve(hi.or(bye));
    server
        .run(SocketAddr::new(
            IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)),
            8000,
        ))
        .await;
}
